# Dispyt 📚
**Dispyt is an API wrapper for the Discord API [Python3].<br/>
Tested in Python version 3.7.1.<br/>
Latest version of the library is 0.0.1b.**

# Installation
Coming soon.

# This is a beta product! 😲
Be careful when using it, is a beta product eventually and it has some bugs.

# Documentation 📃
Coming Soon.

# Todo List 📋
- [ ] All Events
- [ ] Basic Error Handling
- [ ] Commands Error Events
- [ ] All Users Functional
- [ ] All Channels Functional
- [ ] All Guilds Functional
